@@ -1,5 +1,5 @@
 /*
- *  Copyright 2001-2011 Stephen Colebourne
+ *  Copyright 2001-2013 Stephen Colebourne
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -292,10 +292,10 @@ public final class DateTime
      * using <code>ISOChronology</code> in the default time zone.
      *
      * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
+     * @param monthOfYear  the month of the year, from 1 to 12
+     * @param dayOfMonth  the day of the month, from 1 to 31
+     * @param hourOfDay  the hour of the day, from 0 to 23
+     * @param minuteOfHour  the minute of the hour, from 0 to 59
      * @since 2.0
      */
     public DateTime(
@@ -314,10 +314,10 @@ public final class DateTime
      * If the specified time zone is null, the default zone is used.
      *
      * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
+     * @param monthOfYear  the month of the year, from 1 to 12
+     * @param dayOfMonth  the day of the month, from 1 to 31
+     * @param hourOfDay  the hour of the day, from 0 to 23
+     * @param minuteOfHour  the minute of the hour, from 0 to 59
      * @param zone  the time zone, null means default time zone
      * @since 2.0
      */
@@ -339,11 +339,11 @@ public final class DateTime
      * If the chronology is null, <code>ISOChronology</code>
      * in the default time zone is used.
      *
-     * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
+     * @param year  the year, valid values defined by the chronology
+     * @param monthOfYear  the month of the year, valid values defined by the chronology
+     * @param dayOfMonth  the day of the month, valid values defined by the chronology
+     * @param hourOfDay  the hour of the day, valid values defined by the chronology
+     * @param minuteOfHour  the minute of the hour, valid values defined by the chronology
      * @param chronology  the chronology, null means ISOChronology in default zone
      * @since 2.0
      */
@@ -364,11 +364,11 @@ public final class DateTime
      * using <code>ISOChronology</code> in the default time zone.
      *
      * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
-     * @param secondOfMinute  the second of the minute
+     * @param monthOfYear  the month of the year, from 1 to 12
+     * @param dayOfMonth  the day of the month, from 1 to 31
+     * @param hourOfDay  the hour of the day, from 0 to 23
+     * @param minuteOfHour  the minute of the hour, from 0 to 59
+     * @param secondOfMinute  the second of the minute, from 0 to 59
      * @since 2.0
      */
     public DateTime(
@@ -388,11 +388,11 @@ public final class DateTime
      * If the specified time zone is null, the default zone is used.
      *
      * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
-     * @param secondOfMinute  the second of the minute
+     * @param monthOfYear  the month of the year, from 1 to 12
+     * @param dayOfMonth  the day of the month, from 1 to 31
+     * @param hourOfDay  the hour of the day, from 0 to 23
+     * @param minuteOfHour  the minute of the hour, from 0 to 59
+     * @param secondOfMinute  the second of the minute, from 0 to 59
      * @param zone  the time zone, null means default time zone
      * @since 2.0
      */
@@ -415,12 +415,12 @@ public final class DateTime
      * If the chronology is null, <code>ISOChronology</code>
      * in the default time zone is used.
      *
-     * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
-     * @param secondOfMinute  the second of the minute
+     * @param year  the year, valid values defined by the chronology
+     * @param monthOfYear  the month of the year, valid values defined by the chronology
+     * @param dayOfMonth  the day of the month, valid values defined by the chronology
+     * @param hourOfDay  the hour of the day, valid values defined by the chronology
+     * @param minuteOfHour  the minute of the hour, valid values defined by the chronology
+     * @param secondOfMinute  the second of the minute, valid values defined by the chronology
      * @param chronology  the chronology, null means ISOChronology in default zone
      * @since 2.0
      */
@@ -442,12 +442,12 @@ public final class DateTime
      * using <code>ISOChronology</code> in the default time zone.
      *
      * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
-     * @param secondOfMinute  the second of the minute
-     * @param millisOfSecond  the millisecond of the second
+     * @param monthOfYear  the month of the year, from 1 to 12
+     * @param dayOfMonth  the day of the month, from 1 to 31
+     * @param hourOfDay  the hour of the day, from 0 to 23
+     * @param minuteOfHour  the minute of the hour, from 0 to 59
+     * @param secondOfMinute  the second of the minute, from 0 to 59
+     * @param millisOfSecond  the millisecond of the second, from 0 to 999
      */
     public DateTime(
             int year,
@@ -467,12 +467,12 @@ public final class DateTime
      * If the specified time zone is null, the default zone is used.
      *
      * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
-     * @param secondOfMinute  the second of the minute
-     * @param millisOfSecond  the millisecond of the second
+     * @param monthOfYear  the month of the year, from 1 to 12
+     * @param dayOfMonth  the day of the month, from 1 to 31
+     * @param hourOfDay  the hour of the day, from 0 to 23
+     * @param minuteOfHour  the minute of the hour, from 0 to 59
+     * @param secondOfMinute  the second of the minute, from 0 to 59
+     * @param millisOfSecond  the millisecond of the second, from 0 to 999
      * @param zone  the time zone, null means default time zone
      */
     public DateTime(
@@ -495,13 +495,13 @@ public final class DateTime
      * If the chronology is null, <code>ISOChronology</code>
      * in the default time zone is used.
      *
-     * @param year  the year
-     * @param monthOfYear  the month of the year
-     * @param dayOfMonth  the day of the month
-     * @param hourOfDay  the hour of the day
-     * @param minuteOfHour  the minute of the hour
-     * @param secondOfMinute  the second of the minute
-     * @param millisOfSecond  the millisecond of the second
+     * @param year  the year, valid values defined by the chronology
+     * @param monthOfYear  the month of the year, valid values defined by the chronology
+     * @param dayOfMonth  the day of the month, valid values defined by the chronology
+     * @param hourOfDay  the hour of the day, valid values defined by the chronology
+     * @param minuteOfHour  the minute of the hour, valid values defined by the chronology
+     * @param secondOfMinute  the second of the minute, valid values defined by the chronology
+     * @param millisOfSecond  the millisecond of the second, valid values defined by the chronology
      * @param chronology  the chronology, null means ISOChronology in default zone
      */
     public DateTime(
@@ -1498,7 +1498,9 @@ public final class DateTime
      * same millis and chronology.
      * 
      * @return a DateMidnight using the same millis and chronology
+     * @deprecated DateMidnight is deprecated
      */
+    @Deprecated
     public DateMidnight toDateMidnight() {
         return new DateMidnight(getMillis(), getChronology());
     }
@@ -2218,13 +2220,25 @@ public final class DateTime
          * may need to call {@link DateTime#withLaterOffsetAtOverlap()} on the result
          * to force the later time during a DST overlap if desired.
          * <p>
+         * From v2.2, this method handles a daylight svaings time gap, setting the
+         * time to the last instant before the gap.
+         * <p>
          * The DateTime attached to this property is unchanged by this call.
          *
          * @return a copy of the DateTime with this field set to its maximum
          * @since 1.2
          */
         public DateTime withMaximumValue() {
-            return setCopy(getMaximumValue());
+            try {
+                return setCopy(getMaximumValue());
+            } catch (RuntimeException ex) {
+                if (IllegalInstantException.isIllegalInstant(ex)) {
+                    // adding MILLIS_PER_DAY is not perfect, but will work in almost all situations
+                    long beforeGap = getChronology().getZone().previousTransition(getMillis() + DateTimeConstants.MILLIS_PER_DAY);
+                    return new DateTime(beforeGap, getChronology());
+                }
+                throw ex;
+            }
         }
         
         /**
@@ -2235,13 +2249,25 @@ public final class DateTime
          * may need to call {@link DateTime#withEarlierOffsetAtOverlap()} on the result
          * to force the earlier time during a DST overlap if desired.
          * <p>
+         * From v2.2, this method handles a daylight svaings time gap, setting the
+         * time to the first instant after the gap.
+         * <p>
          * The DateTime attached to this property is unchanged by this call.
          *
          * @return a copy of the DateTime with this field set to its minimum
          * @since 1.2
          */
         public DateTime withMinimumValue() {
-            return setCopy(getMinimumValue());
+            try {
+                return setCopy(getMinimumValue());
+            } catch (RuntimeException ex) {
+                if (IllegalInstantException.isIllegalInstant(ex)) {
+                    // subtracting MILLIS_PER_DAY is not perfect, but will work in almost all situations
+                    long afterGap = getChronology().getZone().nextTransition(getMillis() - DateTimeConstants.MILLIS_PER_DAY);
+                    return new DateTime(afterGap, getChronology());
+                }
+                throw ex;
+            }
         }
         
         //-----------------------------------------------------------------------
