@@ -38,6 +38,8 @@ public class TestDateTimeFormatterBuilder extends TestCase {
     private static final DateTimeZone LONDON = DateTimeZone.forID("Europe/London");
     private static final DateTimeZone PARIS = DateTimeZone.forID("Europe/Paris");
     private static final DateTimeZone TOKYO = DateTimeZone.forID("Asia/Tokyo");
+    private static final DateTimeZone NEW_YORK = DateTimeZone.forID("America/New_York");
+    private static final DateTimeZone LOS_ANGELES = DateTimeZone.forID("America/Los_Angeles");
 
     public static void main(String[] args) {
         junit.textui.TestRunner.run(suite());
@@ -133,7 +135,101 @@ public class TestDateTimeFormatterBuilder extends TestCase {
         bld2.appendLiteral('X');
         bld2.append(p);
         bld2.appendLiteral('Z');
-        assertEquals("XYZ", bld2.toFormatter().print(0L));
+        DateTimeFormatter f = bld2.toFormatter();
+        assertEquals(true, f.isPrinter());
+        assertEquals(false, f.isParser());
+        assertEquals("XYZ", f.print(0L));
+    }
+
+    public void test_append_nullPrinter() {
+        try {
+            DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+            bld2.append((DateTimePrinter) null);
+            fail();
+        } catch (IllegalArgumentException ex) {
+            // expected
+        }
+    }
+
+    //-----------------------------------------------------------------------
+    public void test_append_Parser() {
+        DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder();
+        bld.appendLiteral('Y');
+        DateTimeParser p = bld.toParser();
+        
+        DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+        bld2.appendLiteral('X');
+        bld2.append(p);
+        bld2.appendLiteral('Z');
+        DateTimeFormatter f = bld2.toFormatter();
+        assertEquals(false, f.isPrinter());
+        assertEquals(true, f.isParser());
+        assertEquals(0, f.withZoneUTC().parseMillis("XYZ"));
+    }
+
+    public void test_append_nullParser() {
+        try {
+            DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+            bld2.append((DateTimeParser) null);
+            fail();
+        } catch (IllegalArgumentException ex) {
+            // expected
+        }
+    }
+
+    //-----------------------------------------------------------------------
+    public void test_append_Printer_nullParser() {
+        DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder();
+        bld.appendLiteral('Y');
+        DateTimePrinter p = bld.toPrinter();
+        
+        try {
+            DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+            bld2.append(p, (DateTimeParser) null);
+            fail();
+        } catch (IllegalArgumentException ex) {
+            // expected
+        }
+    }
+
+    public void test_append_nullPrinter_Parser() {
+        DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder();
+        bld.appendLiteral('Y');
+        DateTimeParser p = bld.toParser();
+        
+        try {
+            DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+            bld2.append((DateTimePrinter) null, p);
+            fail();
+        } catch (IllegalArgumentException ex) {
+            // expected
+        }
+    }
+
+    //-----------------------------------------------------------------------
+    public void test_appendOptional_Parser() {
+        DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder();
+        bld.appendLiteral('Y');
+        DateTimeParser p = bld.toParser();
+        
+        DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+        bld2.appendLiteral('X');
+        bld2.appendOptional(p);
+        bld2.appendLiteral('Z');
+        DateTimeFormatter f = bld2.toFormatter();
+        assertEquals(false, f.isPrinter());
+        assertEquals(true, f.isParser());
+        assertEquals(0, f.withZoneUTC().parseMillis("XYZ"));
+    }
+
+    public void test_appendOptional_nullParser() {
+        try {
+            DateTimeFormatterBuilder bld2 = new DateTimeFormatterBuilder();
+            bld2.appendOptional((DateTimeParser) null);
+            fail();
+        } catch (IllegalArgumentException ex) {
+            // expected
+        }
     }
 
     //-----------------------------------------------------------------------
@@ -262,6 +358,16 @@ public class TestDateTimeFormatterBuilder extends TestCase {
         assertEquals(dt, f.parseDateTime("2007-03-04 12:30 America/Dawson_Creek"));
     }
 
+    public void test_printParseZoneBahiaBanderas() {
+        DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder()
+            .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneId();
+        DateTimeFormatter f = bld.toFormatter();
+        
+        DateTime dt = new DateTime(2007, 3, 4, 12, 30, 0, DateTimeZone.forID("America/Bahia_Banderas"));
+        assertEquals("2007-03-04 12:30 America/Bahia_Banderas", f.print(dt));
+        assertEquals(dt, f.parseDateTime("2007-03-04 12:30 America/Bahia_Banderas"));
+    }
+
     public void test_printParseOffset() {
         DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder()
             .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneOffset("Z", true, 2, 2);
@@ -374,6 +480,8 @@ public class TestDateTimeFormatterBuilder extends TestCase {
             .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneShortName();
         DateTimeFormatter f = bld.toFormatter().withLocale(Locale.ENGLISH);
         
+        assertEquals(true, f.isPrinter());
+        assertEquals(false, f.isParser());
         DateTime dt1 = new DateTime(2011, 1, 4, 12, 30, 0, LONDON);
         assertEquals("2011-01-04 12:30 GMT", f.print(dt1));
         DateTime dt2 = new DateTime(2011, 7, 4, 12, 30, 0, LONDON);
@@ -381,7 +489,7 @@ public class TestDateTimeFormatterBuilder extends TestCase {
         try {
             f.parseDateTime("2007-03-04 12:30 GMT");
             fail();
-        } catch (IllegalArgumentException e) {
+        } catch (UnsupportedOperationException e) {
         }
     }
 
@@ -393,6 +501,8 @@ public class TestDateTimeFormatterBuilder extends TestCase {
             .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneShortName(lookup);
         DateTimeFormatter f = bld.toFormatter().withLocale(Locale.ENGLISH);
         
+        assertEquals(true, f.isPrinter());
+        assertEquals(true, f.isParser());
         DateTime dt1 = new DateTime(2011, 1, 4, 12, 30, 0, LONDON);
         assertEquals("2011-01-04 12:30 GMT", f.print(dt1));
         DateTime dt2 = new DateTime(2011, 7, 4, 12, 30, 0, LONDON);
@@ -407,12 +517,45 @@ public class TestDateTimeFormatterBuilder extends TestCase {
         }
     }
 
+    public void test_printParseShortNameWithAutoLookup() {
+        DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder()
+            .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneShortName(null);
+        DateTimeFormatter f = bld.toFormatter().withLocale(Locale.ENGLISH);
+        
+        assertEquals(true, f.isPrinter());
+        assertEquals(true, f.isParser());
+        DateTime dt1 = new DateTime(2011, 1, 4, 12, 30, 0, NEW_YORK);
+        assertEquals("2011-01-04 12:30 EST", f.print(dt1));
+        DateTime dt2 = new DateTime(2011, 7, 4, 12, 30, 0, NEW_YORK);
+        assertEquals("2011-07-04 12:30 EDT", f.print(dt2));
+        DateTime dt3 = new DateTime(2011, 1, 4, 12, 30, 0, LOS_ANGELES);
+        assertEquals("2011-01-04 12:30 PST", f.print(dt3));
+        DateTime dt4 = new DateTime(2011, 7, 4, 12, 30, 0, LOS_ANGELES);
+        assertEquals("2011-07-04 12:30 PDT", f.print(dt4));
+        DateTime dt5 = new DateTime(2011, 7, 4, 12, 30, 0, DateTimeZone.UTC);
+        assertEquals("2011-07-04 12:30 UTC", f.print(dt5));
+        
+        assertEquals(dt1.getZone() + " " + f.parseDateTime("2011-01-04 12:30 EST").getZone(), dt1, f.parseDateTime("2011-01-04 12:30 EST"));
+        assertEquals(dt2, f.parseDateTime("2011-07-04 12:30 EDT"));
+        assertEquals(dt3, f.parseDateTime("2011-01-04 12:30 PST"));
+        assertEquals(dt4, f.parseDateTime("2011-07-04 12:30 PDT"));
+        assertEquals(dt5, f.parseDateTime("2011-07-04 12:30 UT"));
+        assertEquals(dt5, f.parseDateTime("2011-07-04 12:30 UTC"));
+        try {
+            f.parseDateTime("2007-03-04 12:30 PPP");
+            fail();
+        } catch (IllegalArgumentException e) {
+        }
+    }
+
     //-----------------------------------------------------------------------
     public void test_printParseLongName() {
         DateTimeFormatterBuilder bld = new DateTimeFormatterBuilder()
             .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneName();
         DateTimeFormatter f = bld.toFormatter().withLocale(Locale.ENGLISH);
         
+        assertEquals(true, f.isPrinter());
+        assertEquals(false, f.isParser());
         DateTime dt1 = new DateTime(2011, 1, 4, 12, 30, 0, LONDON);
         assertEquals("2011-01-04 12:30 Greenwich Mean Time", f.print(dt1));
         DateTime dt2 = new DateTime(2011, 7, 4, 12, 30, 0, LONDON);
@@ -420,7 +563,7 @@ public class TestDateTimeFormatterBuilder extends TestCase {
         try {
             f.parseDateTime("2007-03-04 12:30 GMT");
             fail();
-        } catch (IllegalArgumentException e) {
+        } catch (UnsupportedOperationException e) {
         }
     }
 
@@ -432,6 +575,8 @@ public class TestDateTimeFormatterBuilder extends TestCase {
             .appendPattern("yyyy-MM-dd HH:mm ").appendTimeZoneName(lookup);
         DateTimeFormatter f = bld.toFormatter().withLocale(Locale.ENGLISH);
         
+        assertEquals(true, f.isPrinter());
+        assertEquals(true, f.isParser());
         DateTime dt1 = new DateTime(2011, 1, 4, 12, 30, 0, LONDON);
         assertEquals("2011-01-04 12:30 Greenwich Mean Time", f.print(dt1));
         DateTime dt2 = new DateTime(2011, 7, 4, 12, 30, 0, LONDON);
